@@ -239,6 +239,12 @@ arv_gc_error_get_type (void)
 			{ ARV_GC_ERROR_INVALID_PVALUE,
 			  "ARV_GC_ERROR_INVALID_PVALUE",
 			  "invalid-pvalue" },
+			{ ARV_GC_ERROR_EMPTY_ENUMERATION,
+			  "ARV_GC_ERROR_EMPTY_ENUMERATION",
+			  "empty-enumeration" },
+			{ ARV_GC_ERROR_OUT_OF_RANGE,
+			  "ARV_GC_ERROR_OUT_OF_RANGE",
+			  "out-of-range" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
@@ -725,6 +731,28 @@ arv_gv_stream_packet_resend_get_type (void)
 	return the_type;
 }
 
+#include "arvxmlschema.h"
+
+GType
+arv_xml_schema_error_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_XML_SCHEMA_ERROR_INVALID_STRUCTURE,
+			  "ARV_XML_SCHEMA_ERROR_INVALID_STRUCTURE",
+			  "structure" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvXmlSchemaError"),
+				values);
+	}
+	return the_type;
+}
+
 #include "arvgvcp.h"
 
 GType
