@@ -91,6 +91,11 @@ GType arv_gv_stream_socket_buffer_get_type	(void) G_GNUC_CONST;
 #define ARV_TYPE_GV_STREAM_PACKET_RESEND	(arv_gv_stream_packet_resend_get_type())
 GType arv_gv_stream_packet_resend_get_type	(void) G_GNUC_CONST;
 
+/* Enumerations from "arvxmlschema.h" */
+
+#define ARV_TYPE_XML_SCHEMA_ERROR	(arv_xml_schema_error_get_type())
+GType arv_xml_schema_error_get_type	(void) G_GNUC_CONST;
+
 /* Enumerations from "arvgvcp.h" */
 
 #define ARV_TYPE_GVCP_PACKET_TYPE	(arv_gvcp_packet_type_get_type())
