@@ -265,6 +265,7 @@ arv_gv_interface_device_infos_unref (ArvGvInterfaceDeviceInfos *infos)
 		g_free (infos->user_name);
 		g_free (infos->manufacturer);
 		g_free (infos->serial_number);
+		g_free (infos->model);
 		g_free (infos->mac_string);
 		g_free (infos);
 	}
@@ -379,12 +380,12 @@ arv_gv_interface_update_device_list (ArvInterface *interface, GArray *device_ids
 	GHashTableIter iter;
 	gpointer key, value;
 
+	g_assert (device_ids->len == 0);
+
 	gv_interface = ARV_GV_INTERFACE (interface);
 
 	arv_gv_interface_discover (gv_interface);
 
-	g_array_set_size (device_ids, 0);
-
 	g_hash_table_iter_init (&iter, gv_interface->priv->devices);
 	while (g_hash_table_iter_next (&iter, &key, &value)) {
 		ArvGvInterfaceDeviceInfos *infos = value;
