@@ -93,9 +93,13 @@ typedef struct _ArvFakeDevice		ArvFakeDevice;
 typedef struct _ArvFakeStream		ArvFakeStream;
 typedef struct _ArvFakeCamera		ArvFakeCamera;
 
+typedef struct _ArvGvFakeCamera		ArvGvFakeCamera;
+
 typedef struct _ArvZip			ArvZip;
 typedef struct _ArvZipFile 		ArvZipFile;
 
+typedef struct _ArvXmlSchema 		ArvXmlSchema;
+
 G_END_DECLS
 
 #endif
