@@ -255,6 +255,9 @@ _discover (ArvUvInterface *uv_interface,  GArray *device_ids)
 			    g_free (ids->device);
 			    g_free (ids->physical);
 			    g_free (ids->address);
+			    g_free (ids->vendor);
+			    g_free (ids->model);
+			    g_free (ids->serial_nbr);
 			    g_free (ids);
 		    }
 		}
@@ -272,6 +275,8 @@ arv_uv_interface_update_device_list (ArvInterface *interface, GArray *device_ids
 {
 	ArvUvInterface *uv_interface = ARV_UV_INTERFACE (interface);
 
+	g_assert (device_ids->len == 0);
+
 	_discover (uv_interface, device_ids);
 }
 
