@@ -85,7 +85,7 @@ arv_uv_stream_thread (void *data)
 
 	offset = 0;
 
-	while (!thread_data->cancel) {
+	while (!g_atomic_int_get (&thread_data->cancel)) {
 		size_t size;
 		transferred = 0;
 
@@ -122,12 +122,17 @@ arv_uv_stream_thread (void *data)
 					if (buffer != NULL) {
 						arv_debug_stream_thread ("New leader received while a buffer is still open");
 						buffer->priv->status = ARV_BUFFER_STATUS_MISSING_PACKETS;
+						if (thread_data->callback != NULL)
+							thread_data->callback (thread_data->user_data,
+									       ARV_STREAM_CALLBACK_TYPE_BUFFER_DONE,
+									       buffer);
 						arv_stream_push_output_buffer (thread_data->stream, buffer);
 						thread_data->n_failures++;
 						buffer = NULL;
 					}
 					buffer = arv_stream_pop_input_buffer (thread_data->stream);
 					if (buffer != NULL) {
+						buffer->priv->system_timestamp_ns = g_get_real_time () * 1000LL;
 						buffer->priv->status = ARV_BUFFER_STATUS_FILLING;
 						buffer->priv->gvsp_payload_type = ARV_GVSP_PAYLOAD_TYPE_IMAGE;
 						arv_uvsp_packet_get_region (packet,
@@ -139,6 +144,10 @@ arv_uv_stream_thread (void *data)
 						buffer->priv->frame_id = arv_uvsp_packet_get_frame_id (packet);
 						buffer->priv->timestamp_ns = arv_uvsp_packet_get_timestamp (packet);
 						offset = 0;
+						if (thread_data->callback != NULL)
+							thread_data->callback (thread_data->user_data,
+									       ARV_STREAM_CALLBACK_TYPE_START_BUFFER,
+									       NULL);
 					} else
 						thread_data->n_underruns++;
 					break;
@@ -153,11 +162,19 @@ arv_uv_stream_thread (void *data)
 							arv_debug_stream_thread ("Incomplete image received, dropping");
 
 							buffer->priv->status = ARV_BUFFER_STATUS_SIZE_MISMATCH;
+							if (thread_data->callback != NULL)
+								thread_data->callback (thread_data->user_data,
+										       ARV_STREAM_CALLBACK_TYPE_BUFFER_DONE,
+										       buffer);
 							arv_stream_push_output_buffer (thread_data->stream, buffer);
 							thread_data->n_underruns++;
 							buffer = NULL;
 						} else {
 							buffer->priv->status = ARV_BUFFER_STATUS_SUCCESS;
+							if (thread_data->callback != NULL)
+								thread_data->callback (thread_data->user_data,
+										       ARV_STREAM_CALLBACK_TYPE_BUFFER_DONE,
+										       buffer);
 							arv_stream_push_output_buffer (thread_data->stream, buffer);
 							thread_data->n_completed_buffers++;
 							buffer = NULL;
@@ -319,7 +336,7 @@ arv_uv_stream_finalize (GObject *object)
 
 		thread_data = uv_stream->priv->thread_data;
 
-		thread_data->cancel = TRUE;
+		g_atomic_int_set (&thread_data->cancel, TRUE);
 		g_thread_join (uv_stream->priv->thread);
 
 		si_control = 0x0;
