@@ -119,6 +119,9 @@ main (int argc, char **argv)
 			/* Stop the video stream */
 			arv_camera_stop_acquisition (camera);
 
+			/* Signal must be inhibited to avoid stream thread running after the last unref */
+			arv_stream_set_emit_signals (stream, FALSE);
+
 			g_object_unref (stream);
 		} else
 			printf ("Can't create stream thread (check if the device is not already used)\n");
